/* GNOME-DB - Development Environment
 * Copyright (c) 1998 by Rodrigo Moya
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
#if !defined(__gda_builder_h__)
#  define __gda_builder_h__

#if defined(HAVE_CONFIG_H)
#  include <config.h>
#endif

#include <gda-ui.h>

/*
 * Database interface
 */
extern void builder_database_connect    (GtkWidget *w, gpointer data);
extern void builder_database_disconnect (GtkWidget *w, gpointer data);

/*
 * Global variables (defined in gda-builder-main.c)
 */
extern GtkWidget*      glb_App;
extern GtkWidget*      glb_StatusBar;
extern CORBA_ORB       glb_Orb;
extern Gda_Connection* glb_dbconn;

#endif